@@ -25,6 +25,7 @@ import datetime
 import csv
 from canalyst_candas.version import __version__ as version
 import pickle
+import pkg_resources
 
 from canalyst_candas.configuration.config import Config, resolve_config
 import urllib3
@@ -61,15 +62,15 @@ BRAND_CONFIG_DEFAULTS = {
     "figure_bg_color": "#FFFFFF",
     "vertical_line_color": "#E2E3E3",
     "ax_spine_color": "#C3C2C3",
-    "title_font_path": Path(
-        os.path.dirname(canalyst_candas.__file__) + "/fonts/Barlow-SemiBold.ttf"
+    "title_font_path": pkg_resources.resource_filename(
+        __name__, "fonts/Barlow-SemiBold.ttf"
     ),
-    "body_font_path": Path(
-        os.path.dirname(canalyst_candas.__file__) + "/fonts/Roboto-Regular.ttf"
+    "body_font_path": pkg_resources.resource_filename(
+        __name__, "fonts/Roboto-Regular.ttf"
     ),
     "chart_bg_color": "#161B21",
     "font_color": "#000",
-    "logo_path": Path(os.path.dirname(canalyst_candas.__file__) + "/images/logo.png"),
+    "logo_path": pkg_resources.resource_filename(__name__, "images/logo.png"),
 }
 
 
@@ -241,25 +242,19 @@ class Getter:
 
         Uses local filesystem if no file found on S3
         """
+
         file_ticker = ticker.split(" ")[0]
 
-        if file_type == "pickle":
-            path_name = (
-                f"DATA/{file_ticker}/{ticker}_{type}.pickle"  # first try pickel on s3
-            )
-            df = self.get_pickle_from_s3(path_name)
-            return df
+        dict_file = {"parquet": "get_parquet_from_s3", "pickle": "get_pickle_from_s3"}
 
-        if file_type == "parquet":
-
-            path_name = f"DATA/{file_ticker}/{ticker}_{type}.parquet"
-            df = self.get_parquet_from_s3(path_name)
-            return df
+        path_name = f"DATA/{file_ticker}/{ticker}_{type}.{file_type}"
+        df = getattr(self, dict_file[file_type])(path_name)
 
         if df is None:
 
             path_name = f"DATA/{file_ticker}/{ticker}_{type}.csv"
             df = self.get_csv_from_s3(path_name)
+            df = df.loc[:, ~df.columns.str.contains("^Unnamed")]
 
         if df is None:
             if path.exists(f"{path_name}"):
@@ -268,11 +263,7 @@ class Getter:
         if df is None:
             return None
 
-        keep_cols = []
-        for col in df.columns:
-            if "Unnamed" not in col:
-                keep_cols.append(col)
-        df = df[keep_cols]
+        df = df.loc[:, ~df.columns.str.contains("^Unnamed")]
 
         return df
 
@@ -551,8 +542,7 @@ def get_name_index_from_csv(ticker, config):
     file_ticker = ticker.split(" ")[0]
 
     log = LogFile(default_dir=config.default_dir)
-
-    get_excel_model(ticker, config, default_dir)
+    get_excel_model(config, ticker, default_dir)
 
     path_name = f"{config.default_dir}/DATA/{file_ticker}/"
 
@@ -565,7 +555,6 @@ def get_name_index_from_csv(ticker, config):
     for f_path in cache_files:
         if "~" in f_path or ".csv" in f_path:
             continue
-
         workbook = load_workbook(f_path, data_only=True)
         model_sheet = workbook["Model"]
         list_names = [
@@ -1012,7 +1001,7 @@ def create_drivers_dot(time_series, auth_headers, ticker, config=None, s3_client
 
     file_ticker = ticker.split(" ")[0]
 
-    path_name = f"DATA/{file_ticker}/"
+    path_name = f"DATA/{file_ticker}"
 
     if not config:
         config = settings.CONFIG or resolve_config()
@@ -1025,7 +1014,7 @@ def create_drivers_dot(time_series, auth_headers, ticker, config=None, s3_client
         if dot_file is not None:
             if not os.path.exists(f"{config.default_dir}/{path_name}"):
                 os.makedirs(f"{config.default_dir}/{path_name}")
-            file_name = f"{config.default_dir}/{path_name}" + "drivers.dot"
+            file_name = f"{config.default_dir}/{path_name}/drivers.dot"
             open(file_name, "wb").write(dot_file)
             return file_name
 
@@ -1718,3 +1707,40 @@ def _validate_colors(
         and match_ax_spine_color
         and match_chart_bg_color
     )
+
+
+def unstack_dataframe(
+    df, ticker="", time_series_name=[], period_type="period_end_date"
+):
+    """
+    A function to unstack a dataframe with period_name as index and either all or specific time series names as column headers.
+
+    Parameters
+    ----------
+    ticker: str
+    time_series_name: list
+    period_type: string
+
+    Returns
+    ----------
+    Pandas DataFrame
+    """
+
+    if ticker != "":
+        df = df.loc[df["ticker"] == ticker]
+
+    if type(time_series_name) is list and len(time_series_name):
+        df = df.loc[df["time_series_name"].isin(time_series_name)]
+
+    elif type(time_series_name) is str:
+        df = df.loc[df["time_series_name"] == time_series_name]
+
+    dx = (
+        df[["value", "time_series_name", period_type]]
+        .set_index([period_type, "time_series_name"])
+        .unstack()
+    )
+    dx.columns = ["_".join(column) for column in dx.columns.to_flat_index()]
+    dx = dx.reset_index()
+    dx.columns = [c.replace("value_", "") for c in list(dx.columns)]
+    return dx
